@@ -1,11 +1,7 @@
 from datetime import datetime
 from functools import partial
 
-try:
-    from collections import OrderedDict
-except ImportError:
-    from ordereddict import OrderedDict
-import six
+from collections import OrderedDict
 import sqlalchemy as sa
 from sqlalchemy.ext.compiler import compiles
 
@@ -145,12 +141,9 @@ class TransactionFactory(ModelFactory):
             if manager.user_cls:
                 user_cls = manager.user_cls
                 Base = manager.declarative_base
-                try:
-                    registry = Base.registry._class_registry
-                except AttributeError:  # SQLAlchemy < 1.4
-                    registry = Base._decl_class_registry
+                registry = Base.registry._class_registry
 
-                if isinstance(user_cls, six.string_types):
+                if isinstance(user_cls, str):
                     try:
                         user_cls = registry[user_cls]
                     except KeyError:
@@ -180,7 +173,7 @@ class TransactionFactory(ModelFactory):
                 return '<Transaction %s>' % ', '.join(
                     (
                         '%s=%r' % (field, value)
-                        if not isinstance(value, six.integer_types)
+                        if not isinstance(value, int)
                         # We want the following line to ensure that longs get
                         # shown without the ugly L suffix on python 2.x
                         # versions
